==> querybuilder-1.0.11.tgz: package/src/defaults.js <==
/**
 * Allowed types and their internal representation
 * @type {object.<string, string>}
 * @readonly
 * @private
 */
QueryBuilder.types = {
  'string':   'string',
  'integer':  'number',
  'double':   'number',
  'date':     'datetime',
  'time':     'datetime',
  'datetime': 'datetime',
  'boolean':  'boolean'
};

/**
* Allowed inputs
* @type {string[]}
* @readonly
* @private
*/
QueryBuilder.inputs = [
  'text',
  'number',
  'textarea',
  'radio',
  'checkbox',
  'select'
];

/**
* Runtime modifiable options with `setOptions` method
* @type {string[]}
* @readonly
* @private
*/
QueryBuilder.modifiable_options = [
  'display_errors',
  'allow_groups',
  'allow_empty',
  'default_condition',
  'default_filter'
];

/**
* CSS selectors for common components
* @type {object.<string, string>}
* @readonly
*/
QueryBuilder.selectors = {
  group_container:      '.rules-group-container',
  rule_container:       '.rule-container',
  filter_container:     '.rule-filter-container',
  operator_container:   '.rule-operator-container',
  value_container:      '.rule-value-container',
  error_container:      '.error-container',
  condition_container:  '.rules-group-header .group-conditions',
  tooltip:              '.tooltip-container',
  description:          '.description-container',

  rule_header:          '.rule-header',
  group_header:         '.rules-group-header',
  group_actions:        '.group-actions',
  rule_actions:         '.rule-actions',

  rules_list:           '.rules-group-body>.rules-list',

  group_condition:      '.rules-group-header [name$=_cond]',
  rule_filter:          '.rule-filter-container [name$=_filter]',
  rule_operator:        '.rule-operator-container [name$=_operator]',
  rule_value:           '.rule-value-container [name*=_value_]',

  add_rule:             '[data-add=rule]',
  delete_rule:          '[data-delete=rule]',
  add_group:            '[data-add=group]',
  delete_group:         '[data-delete=group]'
};

/**
* Template strings (see template.js)
* @type {object.<string, string>}
* @readonly
*/
QueryBuilder.templates = {};

/**
* Localized strings (see i18n/)
* @type {object.<string, object>}
* @readonly
*/
QueryBuilder.regional = {};

/**
* Default operators
* @type {object.<string, object>}
* @readonly
*/
QueryBuilder.OPERATORS = {
  equal:            { type: 'equal',            nb_inputs: 1, multiple: false, apply_to: ['string', 'number', 'datetime', 'boolean'] },
  not_equal:        { type: 'not_equal',        nb_inputs: 1, multiple: false, apply_to: ['string', 'number', 'datetime', 'boolean'] },
  in:               { type: 'in',               nb_inputs: 1, multiple: true,  apply_to: ['string', 'number', 'datetime'] },
  not_in:           { type: 'not_in',           nb_inputs: 1, multiple: true,  apply_to: ['string', 'number', 'datetime'] },
  less:             { type: 'less',             nb_inputs: 1, multiple: false, apply_to: ['number', 'datetime'] },
  less_or_equal:    { type: 'less_or_equal',    nb_inputs: 1, multiple: false, apply_to: ['number', 'datetime'] },
  greater:          { type: 'greater',          nb_inputs: 1, multiple: false, apply_to: ['number', 'datetime'] },
  greater_or_equal: { type: 'greater_or_equal', nb_inputs: 1, multiple: false, apply_to: ['number', 'datetime'] },
  between:          { type: 'between',          nb_inputs: 2, multiple: false, apply_to: ['number', 'datetime'] },
  not_between:      { type: 'not_between',      nb_inputs: 2, multiple: false, apply_to: ['number', 'datetime'] },
  begins_with:      { type: 'begins_with',      nb_inputs: 1, multiple: false, apply_to: ['string'] },
  not_begins_with:  { type: 'not_begins_with',  nb_inputs: 1, multiple: false, apply_to: ['string'] },
  contains:         { type: 'contains',         nb_inputs: 1, multiple: false, apply_to: ['string'] },
  not_contains:     { type: 'not_contains',     nb_inputs: 1, multiple: false, apply_to: ['string'] },
  ends_with:        { type: 'ends_with',        nb_inputs: 1, multiple: false, apply_to: ['string'] },
  not_ends_with:    { type: 'not_ends_with',    nb_inputs: 1, multiple: false, apply_to: ['string'] },
  is_empty:         { type: 'is_empty',         nb_inputs: 0, multiple: false, apply_to: ['string'] },
  is_not_empty:     { type: 'is_not_empty',     nb_inputs: 0, multiple: false, apply_to: ['string'] },
  is_null:          { type: 'is_null',          nb_inputs: 0, multiple: false, apply_to: ['string', 'number', 'datetime', 'boolean'] },
  is_not_null:      { type: 'is_not_null',      nb_inputs: 0, multiple: false, apply_to: ['string', 'number', 'datetime', 'boolean'] }
};

/**
* Default configuration
* @type {object}
* @readonly
*/
QueryBuilder.DEFAULTS = {
  filters: [],
  plugins: [],

  sort_filters: false,
  display_errors: true,
  allow_groups: -1,
  allow_empty: false,
  conditions: ['AND', 'OR'],
  default_condition: 'AND',
  inputs_separator: ' , ',
  select_placeholder: 'Select Field',
  display_empty_filter: true,
  default_filter: null,
  optgroups: {},

  default_rule_flags: {
      filter_readonly: false,
      operator_readonly: false,
      value_readonly: false,
      no_delete: false
  },

  default_group_flags: {
      condition_readonly: false,
      no_add_rule: false,
      no_add_group: false,
      no_delete: false
  },

  templates: {
      group: null,
      rule: null,
      filterSelect: null,
      operatorSelect: null,
      ruleValueSelect: null
  },

  lang_code: 'en',
  lang: {},

  operators: [
      'equal',
      'not_equal',
      'in',
      'not_in',
      'less',
      'less_or_equal',
      'greater',
      'greater_or_equal',
      'between',
      'not_between',
      'begins_with',
      'not_begins_with',
      'contains',
      'not_contains',
      'ends_with',
      'not_ends_with',
      'is_empty',
      'is_not_empty',
      'is_null',
      'is_not_null'
  ],

  icons: {
      add_group:    'glyphicon glyphicon-plus-sign',
      add_rule:     'glyphicon glyphicon-plus',
      remove_group: 'glyphicon glyphicon-remove',
      remove_rule:  'glyphicon glyphicon-remove',
      error:        'glyphicon glyphicon-warning-sign',
      tooltip:      'glyphicon glyphicon-info-sign',
  }
};

==> querybuilder-1.0.14.tgz: package/src/defaults.js <==
/**
 * Allowed types and their internal representation
 * @type {object.<string, string>}
 * @readonly
 * @private
 */
QueryBuilder.types = {
  'string':   'string',
  'integer':  'number',
  'double':   'number',
  'date':     'datetime',
  'time':     'datetime',
  'datetime': 'datetime',
  'boolean':  'boolean'
};

/**
* Allowed inputs
* @type {string[]}
* @readonly
* @private
*/
QueryBuilder.inputs = [
  'text',
  'number',
  'textarea',
  'radio',
  'checkbox',
  'select'
];

/**
* Runtime modifiable options with `setOptions` method
* @type {string[]}
* @readonly
* @private
*/
QueryBuilder.modifiable_options = [
  'display_errors',
  'allow_groups',
  'allow_empty',
  'default_condition',
  'default_filter'
];

/**
* CSS selectors for common components
* @type {object.<string, string>}
* @readonly
*/
QueryBuilder.selectors = {
  group_container:      '.rules-group-container',
  rule_container:       '.rule-container',
  filter_container:     '.rule-filter-container',
  operator_container:   '.rule-operator-container',
  value_container:      '.rule-value-container',
  error_container:      '.error-container',
  condition_container:  '.rules-group-header .group-conditions',
  tooltip:              '.tooltip-container',
  description:          '.description-container',

  rule_header:          '.rule-header',
  group_header:         '.rules-group-header',
  group_actions:        '.group-actions',
  rule_actions:         '.rule-actions',

  rules_list:           '.rules-group-body>.rules-list',

  group_condition:      '.rules-group-header [name$=_cond]',
  rule_filter:          '.rule-filter-container [name$=_filter]',
  rule_operator:        '.rule-operator-container [name$=_operator]',
  rule_value:           '.rule-value-container [name*=_value_]',

  add_rule:             '[data-add=rule]',
  delete_rule:          '[data-delete=rule]',
  add_group:            '[data-add=group]',
  delete_group:         '[data-delete=group]'
};

/**
* Template strings (see template.js)
* @type {object.<string, string>}
* @readonly
*/
QueryBuilder.templates = {};

/**
* Localized strings (see i18n/)
* @type {object.<string, object>}
* @readonly
*/
QueryBuilder.regional = {};

/**
* Default operators
* @type {object.<string, object>}
* @readonly
*/
QueryBuilder.OPERATORS = {
  equal:            { type: 'equal',            nb_inputs: 1, multiple: false, apply_to: ['string', 'number', 'datetime', 'boolean'] },
  not_equal:        { type: 'not_equal',        nb_inputs: 1, multiple: false, apply_to: ['string', 'number', 'datetime', 'boolean'] },
  in:               { type: 'in',               nb_inputs: 1, multiple: true,  apply_to: ['string', 'number', 'datetime'] },
  not_in:           { type: 'not_in',           nb_inputs: 1, multiple: true,  apply_to: ['string', 'number', 'datetime'] },
  less:             { type: 'less',             nb_inputs: 1, multiple: false, apply_to: ['number', 'datetime'] },
  less_or_equal:    { type: 'less_or_equal',    nb_inputs: 1, multiple: false, apply_to: ['number', 'datetime'] },
  greater:          { type: 'greater',          nb_inputs: 1, multiple: false, apply_to: ['number', 'datetime'] },
  greater_or_equal: { type: 'greater_or_equal', nb_inputs: 1, multiple: false, apply_to: ['number', 'datetime'] },
  between:          { type: 'between',          nb_inputs: 2, multiple: false, apply_to: ['number', 'datetime'] },
  not_between:      { type: 'not_between',      nb_inputs: 2, multiple: false, apply_to: ['number', 'datetime'] },
  begins_with:      { type: 'begins_with',      nb_inputs: 1, multiple: false, apply_to: ['string'] },
  not_begins_with:  { type: 'not_begins_with',  nb_inputs: 1, multiple: false, apply_to: ['string'] },
  contains:         { type: 'contains',         nb_inputs: 1, multiple: false, apply_to: ['string'] },
  not_contains:     { type: 'not_contains',     nb_inputs: 1, multiple: false, apply_to: ['string'] },
  ends_with:        { type: 'ends_with',        nb_inputs: 1, multiple: false, apply_to: ['string'] },
  not_ends_with:    { type: 'not_ends_with',    nb_inputs: 1, multiple: false, apply_to: ['string'] },
  is_empty:         { type: 'is_empty',         nb_inputs: 0, multiple: false, apply_to: ['string'] },
  is_not_empty:     { type: 'is_not_empty',     nb_inputs: 0, multiple: false, apply_to: ['string'] },
  is_null:          { type: 'is_null',          nb_inputs: 0, multiple: false, apply_to: ['string', 'number', 'datetime', 'boolean'] },
  is_not_null:      { type: 'is_not_null',      nb_inputs: 0, multiple: false, apply_to: ['string', 'number', 'datetime', 'boolean'] }
};

/**
* Default configuration
* @type {object}
* @readonly
*/
QueryBuilder.DEFAULTS = {
  filters: [],
  plugins: [],

  sort_filters: false,
  display_errors: true,
  allow_groups: -1,
  allow_empty: false,
  conditions: ['AND', 'OR'],
  default_condition: 'AND',
  inputs_separator: ' , ',
  select_placeholder: '------',
  display_empty_filter: true,
  default_filter: null,
  optgroups: {},

  default_rule_flags: {
      filter_readonly: false,
      operator_readonly: false,
      value_readonly: false,
      no_delete: false
  },

  default_group_flags: {
      condition_readonly: false,
      no_add_rule: false,
      no_add_group: false,
      no_delete: false
  },

  templates: {
      group: null,
      rule: null,
      filterSelect: null,
      operatorSelect: null,
      ruleValueSelect: null
  },

  lang_code: 'en',
  lang: {},

  operators: [
      'equal',
      'not_equal',
      'in',
      'not_in',
      'less',
      'less_or_equal',
      'greater',
      'greater_or_equal',
      'between',
      'not_between',
      'begins_with',
      'not_begins_with',
      'contains',
      'not_contains',
      'ends_with',
      'not_ends_with',
      'is_empty',
      'is_not_empty',
      'is_null',
      'is_not_null'
  ],

  icons: {
      add_group:    'glyphicon glyphicon-plus-sign',
      add_rule:     'glyphicon glyphicon-plus',
      remove_group: 'glyphicon glyphicon-remove',
      remove_rule:  'glyphicon glyphicon-remove',
      error:        'glyphicon glyphicon-warning-sign',
      tooltip:      'glyphicon glyphicon-info-sign',
  }
};
